@@ -8,6 +8,11 @@ from ironic_discoverd import discoverd
 from ironic_discoverd import firewall
 
 
+def init_conf():
+    discoverd.init_conf()
+    discoverd.CONF.add_section('discoverd')
+
+
 # FIXME(dtantsur): this test suite is far from being complete
 @patch.object(firewall, 'update_filters', autospec=True)
 @patch.object(discoverd, 'get_client', autospec=True)
@@ -28,12 +33,20 @@ class TestProcess(unittest.TestCase):
             'cpu_arch': 'x86_64',
             'memory_mb': 1024,
             'local_gb': 20,
-            'macs': ['11:22:33:44:55:66', 'broken', '', '66:55:44:33:22:11'],
+            'interfaces': {
+                'em1': {'mac': '11:22:33:44:55:66', 'ip': '1.2.3.4'},
+                'em2': {'mac': 'broken', 'ip': '1.2.3.4'},
+                'em3': {'mac': '', 'ip': '1.2.3.4'},
+                'em4': {'mac': '66:55:44:33:22:11', 'ip': '1.2.3.4'},
+                'em5': {'mac': '66:55:44:33:22:11'},
+            }
         }
+        self.macs = ['11:22:33:44:55:66', 'broken', '', '66:55:44:33:22:11']
         firewall.MACS_DISCOVERY = set(['11:22:33:44:55:66',
                                        '66:55:44:33:22:11'])
+        init_conf()
 
-    def test_bmc(self, client_mock, filters_mock):
+    def _do_test_bmc(self, client_mock, filters_mock):
         self.node.driver_info['ipmi_address'] = '1.2.3.4'
         cli = client_mock.return_value
         cli.node.list.return_value = [
@@ -59,6 +72,20 @@ class TestProcess(unittest.TestCase):
         self.assertEqual(set(), firewall.MACS_DISCOVERY)
         cli.node.set_power_state.assert_called_once_with(self.node.uuid, 'off')
 
+    def test_bmc(self, client_mock, filters_mock):
+        self._do_test_bmc(client_mock, filters_mock)
+
+    def test_bmc_deprecated_macs(self, client_mock, filters_mock):
+        del self.data['interfaces']
+        self.data['macs'] = self.macs
+        self._do_test_bmc(client_mock, filters_mock)
+
+    def test_bmc_ports_for_inactive(self, client_mock, filters_mock):
+        del self.data['interfaces']['em4']
+        discoverd.CONF.set('discoverd', 'ports_for_inactive_interfaces',
+                           'true')
+        self._do_test_bmc(client_mock, filters_mock)
+
     def test_macs(self, client_mock, filters_mock):
         discoverd.ALLOW_SEARCH_BY_MAC = True
         cli = client_mock.return_value
@@ -89,12 +116,13 @@ class TestProcess(unittest.TestCase):
 class TestDiscover(unittest.TestCase):
     def setUp(self):
         self.node1 = Mock(driver='pxe_ssh',
-                          uuid='uuid1')
+                          uuid='uuid1',
+                          maintenance=True)
         self.node2 = Mock(driver='pxe_ipmitool',
-                          uuid='uuid2')
+                          uuid='uuid2',
+                          maintenance=False)
         firewall.MACS_DISCOVERY = set()
-        if not discoverd.CONF.has_section('discoverd'):
-            discoverd.CONF.add_section('discoverd')
+        init_conf()
 
     def test(self, client_mock, filters_mock):
         cli = client_mock.return_value
@@ -110,12 +138,15 @@ class TestDiscover(unittest.TestCase):
         discoverd.discover(['uuid%d' % i for i in range(4)])
 
         self.assertEqual(4, cli.node.get.call_count)
-        cli.node.list_ports.assert_called_once_with('uuid1', limit=0)
+        self.assertEqual(2, cli.node.list_ports.call_count)
+        cli.node.list_ports.assert_any_call('uuid1', limit=0)
+        cli.node.list_ports.assert_any_call('uuid2', limit=0)
         filters_mock.assert_called_once_with(cli)
         self.assertEqual(set(['1', '2']), firewall.MACS_DISCOVERY)
         self.assertEqual(2, cli.node.set_power_state.call_count)
         cli.node.set_power_state.assert_called_with(ANY, 'on')
-        patch = [{'op': 'add', 'path': '/extra/on_discovery', 'value': 'true'}]
+        patch = [{'op': 'add', 'path': '/extra/on_discovery', 'value': 'true'},
+                 {'op': 'replace', 'path': '/maintenance', 'value': 'true'}]
         cli.node.update.assert_any_call('uuid1', patch)
         cli.node.update.assert_any_call('uuid3', patch)
         self.assertEqual(2, cli.node.update.call_count)
